==> coos.app-2.2.2.1-sources.jar: top/coos/app/bean/service/ServiceBean.java <==
package top.coos.app.bean.service;

import java.util.List;

import top.coos.app.enums.ModelProcessorType;

public abstract class ServiceBean<T extends ServiceFieldBean> {

	private String name;

	private String type;

	private String paramresolve;

	private String processcondition;

	private String processvalidateclass;

	private String processbeforeclass;

	private String processafterclass;

	private String valueresolve;

	private String resultformat;

	public ModelProcessorType processortype = getProcessortype();

	private List<T> fields;

	private List<ServiceBean<?>> services;

	public List<ServiceBean<?>> getServices() {

		return services;
	}

	public void setServices(List<ServiceBean<?>> services) {

		this.services = services;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public String getProcessvalidateclass() {

		return processvalidateclass;
	}

	public void setProcessvalidateclass(String processvalidateclass) {

		this.processvalidateclass = processvalidateclass;
	}

	public String getProcessbeforeclass() {

		return processbeforeclass;
	}

	public void setProcessbeforeclass(String processbeforeclass) {

		this.processbeforeclass = processbeforeclass;
	}

	public String getProcessafterclass() {

		return processafterclass;
	}

	public void setProcessafterclass(String processafterclass) {

		this.processafterclass = processafterclass;
	}

	public String getValueresolve() {

		return valueresolve;
	}

	public void setValueresolve(String valueresolve) {

		this.valueresolve = valueresolve;
	}

	public String getResultformat() {

		return resultformat;
	}

	public void setResultformat(String resultformat) {

		this.resultformat = resultformat;
	}

	public abstract ModelProcessorType getProcessortype();

	public void setProcessortype(ModelProcessorType processortype) {

		this.processortype = processortype;
	}

	public String getType() {

		return type;
	}

	public void setType(String type) {

		this.type = type;
	}

	public String getParamresolve() {

		return paramresolve;
	}

	public void setParamresolve(String paramresolve) {

		this.paramresolve = paramresolve;
	}

	public String getProcesscondition() {

		return processcondition;
	}

	public void setProcesscondition(String processcondition) {

		this.processcondition = processcondition;
	}

	public List<T> getFields() {

		return fields;
	}

	public void setFields(List<T> fields) {

		this.fields = fields;
	}

}

==> coos.app-2.2.6.9-sources.jar: top/coos/app/bean/service/ServiceBean.java <==
package top.coos.app.bean.service;

import java.util.List;

import top.coos.app.enums.ModelProcessorType;

public abstract class ServiceBean {

	private String name;

	private String type;

	private String paramresolve;

	private String processcondition;

	private String processvalidateclass;

	private String processbeforeclass;

	private String processafterclass;

	private String valueresolve;

	private String resultformat;

	public ModelProcessorType processortype = getProcessortype();

	private List<ServiceBean> services;

	public List<ServiceBean> getServices() {

		return services;
	}

	public void setServices(List<ServiceBean> services) {

		this.services = services;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public String getProcessvalidateclass() {

		return processvalidateclass;
	}

	public void setProcessvalidateclass(String processvalidateclass) {

		this.processvalidateclass = processvalidateclass;
	}

	public String getProcessbeforeclass() {

		return processbeforeclass;
	}

	public void setProcessbeforeclass(String processbeforeclass) {

		this.processbeforeclass = processbeforeclass;
	}

	public String getProcessafterclass() {

		return processafterclass;
	}

	public void setProcessafterclass(String processafterclass) {

		this.processafterclass = processafterclass;
	}

	public String getValueresolve() {

		return valueresolve;
	}

	public void setValueresolve(String valueresolve) {

		this.valueresolve = valueresolve;
	}

	public String getResultformat() {

		return resultformat;
	}

	public void setResultformat(String resultformat) {

		this.resultformat = resultformat;
	}

	public abstract ModelProcessorType getProcessortype();

	public void setProcessortype(ModelProcessorType processortype) {

		this.processortype = processortype;
	}

	public String getType() {

		return type;
	}

	public void setType(String type) {

		this.type = type;
	}

	public String getParamresolve() {

		return paramresolve;
	}

	public void setParamresolve(String paramresolve) {

		this.paramresolve = paramresolve;
	}

	public String getProcesscondition() {

		return processcondition;
	}

	public void setProcesscondition(String processcondition) {

		this.processcondition = processcondition;
	}

}
